@@ -3,7 +3,7 @@
 # 	if(!require(topGO) | !require(annotate))
 # 		stop("Packages topGO and annotate required for function GOenrichment")
 # 	ontology = get("ontology", envir=GOSimEnv)
-# 	gomap <- get("gomap",env=GOSimEnv)	
+# 	gomap <- get("gomap",envir=GOSimEnv)	
 # 	anno <- gomap[names(allpvalues)]
 # 	goterms = lapply(anno, function(x) sapply(x, function(y) y$Ontology == ontology))
 # 	goterms = goterms[!is.na(names(goterms))]
@@ -29,6 +29,7 @@
 GOenrichment = function(genesOfInterest, allgenes, cutoff=0.01, method="elim"){
 	if(!require(topGO) | !require(annotate))		
 		stop("Packages topGO and annotate required for function analyzeCluster")	
+	if(!exists("GOSimEnv")) initialize()		
 	ontology = get("ontology", envir=GOSimEnv)		
 	topgenes = function(allScore){				
 		return(names(allgenes) %in% names(genesOfInterest))		
@@ -50,7 +51,7 @@ GOenrichment = function(genesOfInterest, allgenes, cutoff=0.01, method="elim"){
 	else
 		stop("Parameters 'allgenes' and 'genesOfInterest' have either to be character vectors of Entrez gene IDs or vectors of p-values named with Entrez gene IDs")
 
-	gomap <- get("gomap",env=GOSimEnv)	
+	gomap <- get("gomap",envir=GOSimEnv)	
 	anno <- gomap[geneIDs]
 	goterms = lapply(anno, function(x) sapply(x, function(y) y$Ontology == ontology))
 	goterms = goterms[!is.na(names(goterms))]
