@@ -1,9 +1,9 @@
 initialize<-function(){
-	print("initializing GOSim package ...")		
+	message("initializing GOSim package ...")		
 	assign("GOSimEnv",new.env(parent=globalenv()),envir=.GlobalEnv)  	
   	setEvidenceLevel("all", organism="human")
   	setOntology("BP")
-  	print("finished.")
+  	message("finished.")
 }
 
 getOffsprings<-function(){
@@ -69,7 +69,7 @@ getChildren<-function(){
 # filter GO mapping for given evidence levels
 setEvidenceLevel<-function(evidences="all", organism=org.Hs.egORGANISM, gomap=org.Hs.egGO){			
         if(!exists("GOSimEnv")) initialize()	
-	print(paste("-> retrieving GO information for all available genes for organism '", organism, "' in GO database", sep=""))
+	message(paste("-> retrieving GO information for all available genes for organism '", organism, "' in GO database", sep=""))
 	assign("evidences", evidences, envir=GOSimEnv)	
 # 	gomap<-as.list(GOENTREZID2GO)		
 	if(is(gomap, "Bimap")){		
@@ -78,7 +78,7 @@ setEvidenceLevel<-function(evidences="all", organism=org.Hs.egORGANISM, gomap=or
 	}
 	else if(!is(gomap, "list"))
 		stop("gomap argument should be a nested list (see manual pages)!")
-	print(paste("-> filtering GO terms according to evidence levels '", evidences, "'",sep=""))
+	message(paste("-> filtering GO terms according to evidence levels '", evidences, "'",sep=""))
 	if((length(evidences) > 1) || (evidences!="all")){		
 		gomap<-sapply(gomap,function(x) sapply(x,function(y) c(y$Evidence %in% evidences, y$Ontology)))
 		gomap<-sapply(gomap, function(x) x[2,x[1,]=="TRUE"])
@@ -93,7 +93,7 @@ setOntology<-function(ont="BP", loadIC=TRUE, DIR=NULL){
 	assign("ontology", ont, envir=GOSimEnv)		
 	if(loadIC){
 		organism = get("organism", envir=GOSimEnv)
-		print(paste("-> loading files with information content for corresponding GO category (",organism,")",sep=""))
+		message(paste("-> loading files with information content for corresponding GO category (",organism,")",sep=""))
 		ontology<-get("ontology",envir=GOSimEnv)
 		evidences<-get("evidences",envir=GOSimEnv)			
 		fname = paste("ICs",ontology,organism, paste(evidences,collapse="_"),sep="")
@@ -102,7 +102,7 @@ setOntology<-function(ont="BP", loadIC=TRUE, DIR=NULL){
 		else
 			load(file=file.path(DIR, paste(fname, ".rda", sep="")), envir=GOSimEnv)
 		IC<-get("IC",envir=GOSimEnv)
-		IC<-IC/max(IC[IC!=Inf])
+		#IC<-IC/max(IC[IC!=Inf])
 		IC["all"]=0
 		assign("IC", IC, envir=GOSimEnv)
 	}
